==> de.uka.ipd.sdq.pcm.codegen.simucom.source_1.0.0.201511051246.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/CalculatorsXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import org.eclipse.xtend2.lib.StringConcatenation;
import org.palladiosimulator.pcm.seff.ExternalCallAction;
import org.palladiosimulator.pcm.usagemodel.UsageScenario;

@SuppressWarnings("all")
public class CalculatorsXpt {
  public CharSequence setupCalculatorResponseTime(final String s, final String startProbeSetId, final String endProbeSetId) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("java.util.List<org.palladiosimulator.probeframework.probes.Probe> probes = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("java.util.Arrays.asList(");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("(org.palladiosimulator.probeframework.probes.Probe)new de.uka.ipd.sdq.simucomframework.probes.TakeCurrentSimulationTimeProbe(getModel().getSimulationControl()),");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("(org.palladiosimulator.probeframework.probes.Probe)new de.uka.ipd.sdq.simucomframework.probes.TakeCurrentSimulationTimeProbe(getModel().getSimulationControl()));");
    _builder.newLine();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// TODO get rid of StringMeasuringPoint and use a more concrete one.");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.StringMeasuringPoint mp = measuringpointFactory.createStringMeasuringPoint();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("mp.setMeasuringPoint(\"");
    _builder.append(s, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.MeasuringPointRepository myMeasurementPointRepository = ");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.MeasuringpointFactory.eINSTANCE.createMeasuringPointRepository();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("myMeasurementPointRepository.getMeasuringPoints().add(mp);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("mp.setMeasuringPointRepository(myMeasurementPointRepository);");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("getModel().getProbeFrameworkContext().getCalculatorFactory().buildResponseTimeCalculator(mp,probes);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("this.startStopProbes.put(\"");
    _builder.append(s, "\t");
    _builder.append("\",probes);");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence setupCalculatorExecutionResult(final UsageScenario us) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("//Newer Version has bugs so this old version is just commented out");
    _builder.newLine();
    _builder.append("//getModel().getProbeSpecContext().getCalculatorRegistry().registerCalculator(");
    _builder.newLine();
    _builder.append("//\t\"");
    String _entityName = us.getEntityName();
    _builder.append(_entityName, "");
    _builder.append("/");
    String _id = us.getId();
    _builder.append(_id, "");
    _builder.append("/ExecutionResult\",");
    _builder.newLineIfNotEmpty();
    _builder.append("//\tgetModel().getProbeSpecContext().getCalculatorFactory().buildExecutionResultCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\"UsageScenario ");
    String _entityName_1 = us.getEntityName();
    _builder.append(_entityName_1, "");
    _builder.append(" <");
    String _id_1 = us.getId();
    _builder.append(_id_1, "");
    _builder.append(">\", ");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\tgetModel().getProbeSpecContext().obtainProbeSetId(");
    _builder.newLine();
    _builder.append("//\t\t\tde.uka.ipd.sdq.simucomframework.ReliabilitySensorHelper.getScenarioProbeSetId(");
    _builder.newLine();
    _builder.append("//\t\t\t\t\"");
    String _id_2 = us.getId();
    _builder.append(_id_2, "");
    _builder.append("\"))));");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence setupCalculatorExecutionResult(final ExternalCallAction eac, final String callName) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("//See method above");
    _builder.newLine();
    _builder.append("//\tgetModel().getProbeSpecContext().getCalculatorRegistry().registerCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\"");
    String _entityName = eac.getEntityName();
    _builder.append(_entityName, "");
    _builder.append("/");
    String _id = eac.getId();
    _builder.append(_id, "");
    _builder.append("/ExecutionResult\",");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\tgetModel().getProbeSpecContext().getCalculatorFactory().buildExecutionResultCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\t\"");
    _builder.append(callName, "");
    _builder.append("\", ");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\t\tgetModel().getProbeSpecContext().obtainProbeSetId(\"");
    _builder.append(callName, "");
    _builder.append("\")));");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}

==> de.uka.ipd.sdq.pcm.codegen.simucom.source_5.2.2.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/CalculatorsXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import org.eclipse.xtend2.lib.StringConcatenation;
import org.palladiosimulator.pcm.seff.ExternalCallAction;
import org.palladiosimulator.pcm.usagemodel.UsageScenario;

@SuppressWarnings("all")
public class CalculatorsXpt {
  public CharSequence setupCalculatorResponseTime(final String s, final String startProbeSetId, final String endProbeSetId) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("java.util.List<org.palladiosimulator.probeframework.probes.Probe> probes = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("java.util.Arrays.asList(");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("(org.palladiosimulator.probeframework.probes.Probe)new de.uka.ipd.sdq.simucomframework.probes.TakeCurrentSimulationTimeProbe(getModel().getSimulationControl()),");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("(org.palladiosimulator.probeframework.probes.Probe)new de.uka.ipd.sdq.simucomframework.probes.TakeCurrentSimulationTimeProbe(getModel().getSimulationControl()));");
    _builder.newLine();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// TODO get rid of StringMeasuringPoint and use a more concrete one.");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.StringMeasuringPoint mp = measuringpointFactory.createStringMeasuringPoint();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("mp.setMeasuringPoint(\"");
    _builder.append(s, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.MeasuringPointRepository myMeasurementPointRepository = ");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("org.palladiosimulator.edp2.models.measuringpoint.MeasuringpointFactory.eINSTANCE.createMeasuringPointRepository();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("myMeasurementPointRepository.getMeasuringPoints().add(mp);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("mp.setMeasuringPointRepository(myMeasurementPointRepository);");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("getModel().getProbeFrameworkContext().getCalculatorFactory().buildResponseTimeCalculator(mp,probes);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("this.startStopProbes.put(\"");
    _builder.append(s, "\t");
    _builder.append("\",probes);");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }

  public CharSequence setupCalculatorExecutionResult(final UsageScenario us) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("//Newer Version has bugs so this old version is just commented out");
    _builder.newLine();
    _builder.append("//getModel().getProbeSpecContext().getCalculatorRegistry().registerCalculator(");
    _builder.newLine();
    _builder.append("//\t\"");
    String _entityName = us.getEntityName();
    _builder.append(_entityName);
    _builder.append("/");
    String _id = us.getId();
    _builder.append(_id);
    _builder.append("/ExecutionResult\",");
    _builder.newLineIfNotEmpty();
    _builder.append("//\tgetModel().getProbeSpecContext().getCalculatorFactory().buildExecutionResultCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\"UsageScenario ");
    String _entityName_1 = us.getEntityName();
    _builder.append(_entityName_1);
    _builder.append(" <");
    String _id_1 = us.getId();
    _builder.append(_id_1);
    _builder.append(">\", ");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\tgetModel().getProbeSpecContext().obtainProbeSetId(");
    _builder.newLine();
    _builder.append("//\t\t\tde.uka.ipd.sdq.simucomframework.ReliabilitySensorHelper.getScenarioProbeSetId(");
    _builder.newLine();
    _builder.append("//\t\t\t\t\"");
    String _id_2 = us.getId();
    _builder.append(_id_2);
    _builder.append("\"))));");
    _builder.newLineIfNotEmpty();
    return _builder;
  }

  public CharSequence setupCalculatorExecutionResult(final ExternalCallAction eac, final String callName) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("//See method above");
    _builder.newLine();
    _builder.append("//\tgetModel().getProbeSpecContext().getCalculatorRegistry().registerCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\"");
    String _entityName = eac.getEntityName();
    _builder.append(_entityName);
    _builder.append("/");
    String _id = eac.getId();
    _builder.append(_id);
    _builder.append("/ExecutionResult\",");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\tgetModel().getProbeSpecContext().getCalculatorFactory().buildExecutionResultCalculator(");
    _builder.newLine();
    _builder.append("//\t\t\t\"");
    _builder.append(callName);
    _builder.append("\", ");
    _builder.newLineIfNotEmpty();
    _builder.append("//\t\t\tgetModel().getProbeSpecContext().obtainProbeSetId(\"");
    _builder.append(callName);
    _builder.append("\")));");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}
